MorphIndices

Enum MorphIndices 

pub enum MorphIndices {
    Uniform {
        current: HashMap<MainEntity, MorphIndex, EntityHash>,
        prev: HashMap<MainEntity, MorphIndex, EntityHash>,
    },
    Storage {
        morph_weights_info: HashMap<MainEntity, MorphWeightsInfo, EntityHash>,
        gpu_descriptor_indices: HashMap<MainEntity, MorphDescriptorIndex, EntityHash>,
        gpu_descriptor_free_list: Vec<MorphDescriptorIndex>,
    },
}
Maps each mesh affected by morph targets to the applicable offset within the MorphUniforms buffer.

We store both the current frame’s mapping and the previous frame’s mapping for the purposes of motion vector calculation.

Variants



Uniform

The variant used when storage buffers aren’t supported on the current platform.

Fields

current: HashMap<MainEntity, MorphIndex, EntityHash>

Maps each entity with a morphed mesh to the appropriate offset within MorphUniforms::current_buffer.

prev: HashMap<MainEntity, MorphIndex, EntityHash>

Maps each entity with a morphed mesh to the appropriate offset within MorphUniforms::prev_buffer.



Storage

The variant used when storage buffers are supported on the current platform.

Fields

morph_weights_info: HashMap<MainEntity, MorphWeightsInfo, EntityHash>

Maps each entity with a morphed mesh to the MorphWeightsInfo.

gpu_descriptor_indices: HashMap<MainEntity, MorphDescriptorIndex, EntityHash>

Maps each entity with a morphed mesh to the GpuMorphDescriptor in the morph_descriptors buffer.

gpu_descriptor_free_list: Vec<MorphDescriptorIndex>

Indices in the morph_descriptors buffer available for use.

Implementations

Source

impl MorphIndices

pub fn morph_descriptor_index( &self, main_entity: MainEntity, ) -> Option<MorphDescriptorIndex>

Returns the index of the morph descriptor in the morph descriptor table for the given entity.

As morph descriptors are only present if the platform supports storage buffers, this method returns None if the platform doesn’t support them.