pub struct ContactShadows {
pub linear_steps: u32,
pub thickness: f32,
pub length: f32,
}Expand description
Add this component to a camera to enable contact shadows.
Contact shadows are a screen-space technique that adds small-scale shadows in areas where traditional shadow maps may lack detail, such as where objects touch the ground.
This can be used in forward or deferred rendering, but the depth prepass is required.
Fields
linear_steps: u32The number of steps to be taken at regular intervals to find an initial intersection.
thickness: f32When marching the depth buffer, we only have 2.5D information and don’t know how thick surfaces are. We shall assume that the depth buffer fragments are cuboids with a constant thickness defined by this parameter.
length: f32The length of the contact shadow ray in world space.