#[repr(C)]pub struct GpuMorphDescriptor {
pub current_weights_offset: u32,
pub prev_weights_offset: u32,
pub targets_offset: u32,
pub vertex_count: u32,
pub weight_count: u32,
}Expand description
Information that the GPU needs about a single mesh instance that uses morph targets.
Fields
current_weights_offset: u32The index of the first morph target weight in the morph_weights array.
prev_weights_offset: u32The index of the first morph target weight in the prev_morph_weights
array.
targets_offset: u32The index of the first morph target for this mesh in the
MorphAttributes array.
vertex_count: u32The number of vertices in the mesh.
weight_count: u32The number of morph targets this mesh has.