pub struct MeshFlags(/* private fields */);Expand description
Various flags and tightly-packed values on a mesh.
Flags grow from the top bit down; other values grow from the bottom bit up.
Implementations
Sourceimpl MeshFlags
impl MeshFlags
Sourcepub const LOD_INDEX_MASK: MeshFlags
pub const LOD_INDEX_MASK: MeshFlags
Bitmask for the 16-bit index into the LOD array.
This will be u16::MAX if this mesh has no LOD.
Sourcepub const AABB_BASED_VISIBILITY_RANGE: MeshFlags
pub const AABB_BASED_VISIBILITY_RANGE: MeshFlags
Whether visibility ranges use the center of the AABB to compute distance from the camera.
If false, this uses distance from the world-space translation of the mesh instead.
Sourcepub const NO_FRUSTUM_CULLING: MeshFlags
pub const NO_FRUSTUM_CULLING: MeshFlags
Disables frustum culling for this mesh.
This corresponds to the
[bevy_render::view::visibility::NoFrustumCulling] component.
pub const SHADOW_RECEIVER: MeshFlags
pub const TRANSMITTED_SHADOW_RECEIVER: MeshFlags
pub const SIGN_DETERMINANT_MODEL_3X3: MeshFlags
pub const NONE: MeshFlags
pub const UNINITIALIZED: MeshFlags
Sourceimpl MeshFlags
impl MeshFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<MeshFlags>
pub const fn from_bits(bits: u32) -> Option<MeshFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> MeshFlags
pub const fn from_bits_truncate(bits: u32) -> MeshFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> MeshFlags
pub const fn from_bits_retain(bits: u32) -> MeshFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<MeshFlags>
pub fn from_name(name: &str) -> Option<MeshFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: MeshFlags) -> bool
pub const fn intersects(&self, other: MeshFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: MeshFlags) -> bool
pub const fn contains(&self, other: MeshFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: MeshFlags)
pub fn remove(&mut self, other: MeshFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: MeshFlags)
pub fn toggle(&mut self, other: MeshFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: MeshFlags, value: bool)
pub fn set(&mut self, other: MeshFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: MeshFlags) -> MeshFlags
pub const fn intersection(self, other: MeshFlags) -> MeshFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: MeshFlags) -> MeshFlags
pub const fn union(self, other: MeshFlags) -> MeshFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: MeshFlags) -> MeshFlags
pub const fn difference(self, other: MeshFlags) -> MeshFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: MeshFlags) -> MeshFlags
pub const fn symmetric_difference(self, other: MeshFlags) -> MeshFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> MeshFlags
pub const fn complement(self) -> MeshFlags
The bitwise negation (!) of the bits in self, truncating the result.