MeshInputUniform

Struct MeshInputUniform 

#[repr(C)]
pub struct MeshInputUniform { pub world_from_local: [Vec4; 3], pub lightmap_uv_rect: UVec2, pub flags: u32, pub previous_input_index: u32, pub first_vertex_index: u32, pub first_index_index: u32, pub index_count: u32, pub current_skin_index: u32, pub material_and_lightmap_bind_group_slot: u32, pub timestamp: u32, pub tag: u32, pub morph_descriptor_index: u32, }
Information that has to be transferred from CPU to GPU in order to produce the full MeshUniform.

This is essentially a subset of the fields in MeshUniform above.

Fields

world_from_local: [Vec4; 3]

Affine 4x3 matrix transposed to 3x4.

lightmap_uv_rect: UVec2

Four 16-bit unsigned normalized UV values packed into a UVec2:

                        <--- MSB                   LSB --->
                        +---- min v ----+ +---- min u ----+
    lightmap_uv_rect.x: vvvvvvvv vvvvvvvv uuuuuuuu uuuuuuuu,
                        +---- max v ----+ +---- max u ----+
    lightmap_uv_rect.y: VVVVVVVV VVVVVVVV UUUUUUUU UUUUUUUU,

(MSB: most significant bit; LSB: least significant bit.)
flags: u32

Various MeshFlags.

previous_input_index: u32

The index of this mesh’s MeshInputUniform in the previous frame’s buffer, if applicable.

This is used for TAA. If not present, this will be u32::MAX.

first_vertex_index: u32

The index of this mesh’s first vertex in the vertex buffer.

Multiple meshes can be packed into a single vertex buffer (see MeshAllocator). This value stores the offset of the first vertex in this mesh in that buffer.

first_index_index: u32

The index of this mesh’s first index in the index buffer, if any.

Multiple meshes can be packed into a single index buffer (see MeshAllocator). This value stores the offset of the first index in this mesh in that buffer.

If this mesh isn’t indexed, this value is ignored.

index_count: u32

For an indexed mesh, the number of indices that make it up; for a non-indexed mesh, the number of vertices in it.

current_skin_index: u32

The current skin index, or u32::MAX if there’s no skin.

material_and_lightmap_bind_group_slot: u32

The material and lightmap indices, packed into 32 bits.

Low 16 bits: index of the material inside the bind group data. High 16 bits: index of the lightmap in the binding array.

timestamp: u32

The number of the frame on which this MeshInputUniform was built.

This is used to validate the previous transform and skin. If this MeshInputUniform wasn’t updated on this frame, then we know that neither this mesh’s transform nor that of its joints have been updated on this frame, and therefore the transforms of both this mesh and its joints must be identical to those for the previous frame.

tag: u32

User supplied tag to identify this mesh instance.

morph_descriptor_index: u32

The index of the morph descriptor for this mesh instance in the morph_descriptors table.

If the mesh has no morph targets, this is u32::MAX.