RenderGpuCulledEntities

Struct RenderGpuCulledEntities 

pub struct RenderGpuCulledEntities {
    pub entities: HashMap<MainEntity, RenderLayers, EntityHash>,
    pub added: Vec<MainEntity>,
    pub removed: Vec<MainEntity>,
    pub changed_layers: Vec<MainEntity>,
}
A resource, part of the render world, that stores all entities that are potentially-visible and have NoCpuCulling components.

Even though this resource exists, individual views still have their own lists of all GPU-culled entities, because render layers can alter the set of entities visible to each view.

Fields

entities: HashMap<MainEntity, RenderLayers, EntityHash>

A mapping from each potentially-visible entity to the render layers it’s part of.

added: Vec<MainEntity>

A list of all entities with GPU culling (and no CPU culling) that became potentially visible in some view this frame.

This also includes entities that changed from CPU culling to GPU culling.

Unlike the corresponding field in bevy_render::view::visibility::RenderVisibleEntitiesClass, this list is not necessarily sorted.

removed: Vec<MainEntity>

A list of all entities with GPU culling that were either despawned or otherwise became definitely invisible this frame.

This also includes entities that changed from GPU culling to CPU culling.

Unlike the corresponding field in bevy_render::view::visibility::RenderVisibleEntitiesClass, this list is not necessarily sorted.

changed_layers: Vec<MainEntity>

A list of all entities with GPU culling that changed the set of render layers they belong to this frame.

Implementations

Source

impl RenderGpuCulledEntities

pub fn prepare_for_new_frame(&mut self)

Clears out the sets of newly-added entities, newly-removed entities, and entities that newly changed render layers in preparation for a new frame.

pub fn update( &mut self, new_entity: MainEntity, render_layers: RenderLayers, no_cpu_culling: bool, )

Records that an entity became newly-visible or changed its set of layers this frame.

The render_layers argument specifies the set of render layers that the entity belongs to.

pub fn remove(&mut self, old_entity: MainEntity)

Records that an entity became newly-invisible this frame.