pub struct RenderMeshInstanceSharedFlat { /* private fields */ }Expand description
The thread-safe POD that’s stored for each mesh, common to both the CPU and GPU preprocessing paths.
Fields here are formatted in such a way as to implement bytemuck::Pod:
i.e. with no vectors and no enums. A corresponding
RenderMeshInstanceSharedFlatBlob is provided, for in-place update in
shared memory.