pub struct ScreenSpaceTransmission {
pub steps: usize,
pub quality: ScreenSpaceTransmissionQuality,
}Expand description
Configures transmission behavior, offering a trade-off between performance and visual fidelity.
Fields
steps: usizeHow many individual steps should be performed in the Transmissive3d pass.
Roughly corresponds to how many layers of transparency are rendered for screen space
specular transmissive objects. Each step requires making one additional
texture copy, so it’s recommended to keep this number to a reasonably low value. Defaults to 1.
Notes
- No copies will be performed if there are no transmissive materials currently being rendered, regardless of this setting.
- Setting this to
0disables the screen-space refraction effect entirely, and falls back to refracting only the environment map light’s texture. - If set to more than
0, any opaqueclear_colorwill obscure the environment map light’s texture, preventing it from being visible through transmissive materials. If you’d like to still have the environment map show up in your refractions, you can set the clear color’s alpha to0.0. Keep in mind that depending on the platform and your window settings, this may cause the window to become transparent.
quality: ScreenSpaceTransmissionQualityThe quality of the screen space specular transmission blur effect, applied to whatever’s behind transmissive
objects when their roughness is greater than 0.0.
Higher qualities are more GPU-intensive.
Note: You can get better-looking results at any quality level by enabling TAA. See: TemporalAntiAliasPlugin